/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.weather.web.internal.portlet.action;

import com.liferay.portal.kernel.portlet.ConfigurationAction;
import com.liferay.portal.kernel.portlet.DefaultConfigurationAction;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.weather.web.internal.constants.WeatherPortletKeys;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletConfig;
import javax.portlet.ValidatorException;

import org.osgi.service.component.annotations.Component;

/**
 * @author Samuel Kong
 * @author Peter Fellwock
 */
@Component(
	immediate = true,
	property = {"javax.portlet.name=" + WeatherPortletKeys.WEATHER},
	service = ConfigurationAction.class
)
public class WeatherConfigurationAction extends DefaultConfigurationAction {

	@Override
	public void processAction(
			PortletConfig portletConfig, ActionRequest actionRequest,
			ActionResponse actionResponse)
		throws Exception {

		String apiKey = getParameter(actionRequest, "apiKey");

		setPreference(actionRequest, "apiKey", apiKey);

		String[] zips = StringUtil.split(
			getParameter(actionRequest, "zips"), StringPool.NEW_LINE);

		setPreference(actionRequest, "zips", zips);

		try {
			super.processAction(portletConfig, actionRequest, actionResponse);
		}
		catch (ValidatorException ve) {
			SessionErrors.add(
				actionRequest, ValidatorException.class.getName(), ve);
		}
	}

}