/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.weather.web.internal.portlet.validator;

import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.weather.web.internal.constants.WeatherPortletKeys;
import com.liferay.weather.web.internal.model.Weather;
import com.liferay.weather.web.internal.util.WeatherUtil;

import java.util.ArrayList;
import java.util.List;

import javax.portlet.PortletPreferences;
import javax.portlet.PreferencesValidator;
import javax.portlet.ValidatorException;

import org.osgi.service.component.annotations.Component;

/**
 * @author Brian Wing Shun Chan
 */
@Component(
	immediate = true,
	property = {"javax.portlet.name=" + WeatherPortletKeys.WEATHER}
)
public class WeatherPreferencesValidator implements PreferencesValidator {

	@Override
	public void validate(PortletPreferences preferences)
		throws ValidatorException {

		List<String> badZips = new ArrayList<>();

		String apiKey = preferences.getValue("apiKey", StringPool.BLANK);

		if (Validator.isNull(apiKey)) {
			return;
		}

		String[] zips = preferences.getValues("zips", new String[0]);

		for (String zip : zips) {
			Weather weather = WeatherUtil.getWeather(zip, apiKey);

			if (weather == null) {
				badZips.add(zip);
			}
		}

		if (!badZips.isEmpty()) {
			throw new ValidatorException("Failed to retrieve zips", badZips);
		}
	}

}